==> zio-aws-amplifyuibuilder_2.12-5.17.144.1-sources.jar: zio/aws/amplifyuibuilder/model/ExportThemesRequest.scala <==
package zio.aws.amplifyuibuilder.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ExportThemesRequest(
    appId: String,
    environmentName: String,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.ExportThemesRequest = {
    import ExportThemesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.ExportThemesRequest
      .builder()
      .appId(appId: java.lang.String)
      .environmentName(environmentName: java.lang.String)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.amplifyuibuilder.model.ExportThemesRequest.ReadOnly =
    zio.aws.amplifyuibuilder.model.ExportThemesRequest.wrap(buildAwsValue())
}
object ExportThemesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.ExportThemesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifyuibuilder.model.ExportThemesRequest =
      zio.aws.amplifyuibuilder.model.ExportThemesRequest(
        appId,
        environmentName,
        nextToken.map(value => value)
      )
    def appId: String
    def environmentName: String
    def nextToken: Option[String]
    def getAppId: ZIO[Any, Nothing, String] = ZIO.succeed(appId)
    def getEnvironmentName: ZIO[Any, Nothing, String] =
      ZIO.succeed(environmentName)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ExportThemesRequest
  ) extends zio.aws.amplifyuibuilder.model.ExportThemesRequest.ReadOnly {
    override val appId: String = impl.appId(): String
    override val environmentName: String = impl.environmentName(): String
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ExportThemesRequest
  ): zio.aws.amplifyuibuilder.model.ExportThemesRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-amplifyuibuilder_2.13-5.17.104.4-sources.jar: zio/aws/amplifyuibuilder/model/ExportThemesRequest.scala <==
package zio.aws.amplifyuibuilder.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class ExportThemesRequest(appId: String, environmentName: String) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.ExportThemesRequest = {
    import ExportThemesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.ExportThemesRequest
      .builder()
      .appId(appId: java.lang.String)
      .environmentName(environmentName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.amplifyuibuilder.model.ExportThemesRequest.ReadOnly =
    zio.aws.amplifyuibuilder.model.ExportThemesRequest.wrap(buildAwsValue())
}
object ExportThemesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.ExportThemesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifyuibuilder.model.ExportThemesRequest =
      zio.aws.amplifyuibuilder.model.ExportThemesRequest(appId, environmentName)
    def appId: String
    def environmentName: String
    def getAppId: ZIO[Any, Nothing, String] = ZIO.succeed(appId)
    def getEnvironmentName: ZIO[Any, Nothing, String] =
      ZIO.succeed(environmentName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ExportThemesRequest
  ) extends zio.aws.amplifyuibuilder.model.ExportThemesRequest.ReadOnly {
    override val appId: String = impl.appId(): String
    override val environmentName: String = impl.environmentName(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ExportThemesRequest
  ): zio.aws.amplifyuibuilder.model.ExportThemesRequest.ReadOnly = new Wrapper(
    impl
  )
}
